@@ -138,7 +138,7 @@ int get_backplane_info(int what, SAFTE_T *safte, int controller, int cur_bp){
 	char bus_n[] = "/dev/rd/c0d0";
 	char bus_n_devfs[] = "/dev/rd/disc0/disc";
 	char error_m[80];
-	char tr_data[1024];
+	unsigned char tr_data[1024];
 	DAC960_V1_DCDB_T dcdb;
 	
 
@@ -424,7 +424,6 @@ int detect_backplane(){
 	DAC960_SCSI_Inquiry_T inq;
 	int num_controllers;
 	int controller_number;
-	char tmp[32];
 	struct utsname ut;
 
 	uname(&ut);
@@ -489,19 +488,8 @@ int detect_backplane(){
 #else
 				if (status == 0){
 #endif
-					int index;
-
 					fflush(stdout);
 					status = inquiry(fd, channel, target, &inq, controller_number);
-					strncpy(tmp, inq.VendorIdentification, 8);
-					tmp[8]=0;
-					memset(&tmp[0], 0, sizeof(tmp));
-					index =0;
-					while(isprint(inq.ProductIdentification[index])){
-						tmp[index] = inq.ProductIdentification[index];
-						index++;
-					}
-					tmp[index]=0;
 					if ((!strncmp(inq.VendorIdentification,"QLogic",6)) ||
 						(!strncmp(inq.VendorIdentification,"VA Linux",8))){
 						int k;
@@ -521,8 +509,6 @@ int detect_backplane(){
 
 					}
 				}
-				
-				memset(&tmp[0], 0, sizeof(tmp));
 				}
 	}
 	close(fd);
@@ -878,7 +864,7 @@ Parse the lines into data structure
 This function parses the information from the stream directly
 */
 
-int get_stat(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int state_flag, int no_cards){
+int get_stat(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool){
 	int cur_card, maxx, maxy, del_yy = 2, del_xx = 1;
 	
 	maxy = all_win->status_win->_maxy;
@@ -1831,6 +1817,7 @@ int get_stat(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int state_flag,
 void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int no_cards){
 	int dummy = 0, x = 0, card_focus = 0, tab_focus = 0;
 	int dummy1 = 0;
+        size_t dummy2 = 0;
 	char line[80];
 	
 	if(key_press != KEY_INIT){
@@ -1935,11 +1922,11 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 					else
 						waddch(all_win->status_win, ACS_HLINE);
 
-					for(dummy1 = 0; dummy1 < strlen(tab_pool[dummy].label); dummy1++) waddch(all_win->status_win, ACS_HLINE);
+					for(dummy2 = 0; dummy2 < strlen(tab_pool[dummy].label); dummy2++) waddch(all_win->status_win, ACS_HLINE);
 					waddch(all_win->status_win, ACS_HLINE);
 				}else {
 					waddch(all_win->status_win, tab_pool[dummy].llpad);
-					for(dummy1 = 0; dummy1 < strlen(tab_pool[dummy].label); dummy1++) waddch(all_win->status_win, ' ');
+					for(dummy2 = 0; dummy2 < strlen(tab_pool[dummy].label); dummy2++) waddch(all_win->status_win, ' ');
 					waddch(all_win->status_win, tab_pool[dummy].lrpad);
 				}
 				for(dummy1 = 0; dummy1 < tab_pool[dummy].x; dummy1++) waddch(all_win->status_win, ACS_HLINE);
@@ -1948,7 +1935,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 			whline(all_win->status_win, ACS_HLINE, (all_win->status_win->_maxx-x));
 			mvwaddch(all_win->status_win, 1, all_win->status_win->_maxx, ACS_URCORNER);
 			
-			get_stat(all_win, card_pool, tab_pool, KEY_POST_INIT, no_cards);
+			get_stat(all_win, card_pool, tab_pool);
 			
 			wrefresh(all_win->cardlist);
 			wrefresh(all_win->status_win);
@@ -1972,8 +1959,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 					}
 				}
 
-				get_stat(all_win, card_pool, tab_pool,
-				KEY_DOWN, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				wrefresh(all_win->status_win);
 				refresh();
 				break;
@@ -1993,8 +1979,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 							break;
 						}
 					}
-				get_stat(all_win, card_pool, tab_pool,
-				KEY_DOWN, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				wrefresh(all_win->status_win);
 				refresh();
 				break;
@@ -2017,8 +2002,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 							break;
 						}
 					}
-				get_stat(all_win, card_pool, tab_pool,
-				KEY_DOWN, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				wrefresh(all_win->status_win);
 				refresh();
 				break;
@@ -2079,8 +2063,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 		        
 			wattrset(all_win->cardlist, CARDLIST_NOFOCUS);
 
-			get_stat(all_win, card_pool, tab_pool,
-			KEY_DOWN, no_cards);
+			get_stat(all_win, card_pool, tab_pool);
 
 			wrefresh(all_win->status_win);
 			
@@ -2102,8 +2085,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 					}
 				}
 
-				get_stat(all_win, card_pool, tab_pool,
-				KEY_DOWN, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				wrefresh(all_win->status_win);
 				refresh();
 				break;
@@ -2128,8 +2110,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 							break;
 						}
 					}
-				get_stat(all_win, card_pool, tab_pool,
-				KEY_UP, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				wrefresh(all_win->status_win);
 				refresh();
 				break;
@@ -2156,8 +2137,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 							break;
 						}
 					}
-				get_stat(all_win, card_pool, tab_pool,
-				KEY_UP, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				wrefresh(all_win->status_win);
 				refresh();
 				break;
@@ -2215,8 +2195,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 			
 			wattrset(all_win->cardlist, CARDLIST_NOFOCUS);
 
-			get_stat(all_win, card_pool, tab_pool,
-			KEY_UP, no_cards);
+			get_stat(all_win, card_pool, tab_pool);
 
 			wrefresh(all_win->status_win);
 			
@@ -2259,7 +2238,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 					
 			mvwaddstr(all_win->cardlist, card_pool[card_focus].y,
 			card_pool[card_focus].x, line);
-			get_stat(all_win, card_pool, tab_pool, KEY_RETURN, no_cards);
+			get_stat(all_win, card_pool, tab_pool);
 			wrefresh(all_win->status_win);
 			wrefresh(all_win->cardlist);
 
@@ -2396,7 +2375,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 					cmd[i].focus = 0;
 				cmd[0].focus = '0';
 
-				get_stat(all_win, card_pool, tab_pool, KEY_RETURN, no_cards);
+				get_stat(all_win, card_pool, tab_pool);
 				
 	            wattrset(all_win->cardlist, CARDLIST_NOFOCUS); 
 				wrefresh(all_win->cardlist);
@@ -2457,11 +2436,11 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 				if(!tab_pool[dummy].focus){
 					if(dummy) waddch(all_win->status_win, ACS_HLINE);
 					else waddch(all_win->status_win, ACS_ULCORNER);
-					for(dummy1 = 0; dummy1 < strlen(tab_pool[dummy].label); dummy1++) waddch(all_win->status_win, ACS_HLINE);
+					for(dummy2 = 0; dummy2 < strlen(tab_pool[dummy].label); dummy2++) waddch(all_win->status_win, ACS_HLINE);
 					waddch(all_win->status_win, ACS_HLINE);
 				}else {
 					waddch(all_win->status_win, tab_pool[dummy].llpad);
-					for(dummy1 = 0; dummy1 < strlen(tab_pool[dummy].label); dummy1++) waddch(all_win->status_win, ' ');
+					for(dummy2 = 0; dummy2 < strlen(tab_pool[dummy].label); dummy2++) waddch(all_win->status_win, ' ');
 					waddch(all_win->status_win, tab_pool[dummy].lrpad);
 				}
 				for(dummy1 = 0; dummy1 < tab_pool[dummy].x; dummy1++) waddch(all_win->status_win, ACS_HLINE);
@@ -2471,8 +2450,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 			mvwaddch(all_win->status_win, 1, all_win->status_win->_maxx, ACS_URCORNER);
 			dummy = 0;
 			
-			get_stat(all_win, card_pool, tab_pool,
-			KEY_RIGHT, no_cards);
+			get_stat(all_win, card_pool, tab_pool);
 			
 			wrefresh(all_win->status_win);
 			wrefresh(all_win->cardlist);
@@ -2534,11 +2512,11 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 				if(!tab_pool[dummy].focus){
 					if(dummy) waddch(all_win->status_win, ACS_HLINE);
 					else waddch(all_win->status_win, ACS_ULCORNER);
-					for(dummy1 = 0; dummy1 < strlen(tab_pool[dummy].label); dummy1++) waddch(all_win->status_win, ACS_HLINE);
+					for(dummy2 = 0; dummy2 < strlen(tab_pool[dummy].label); dummy2++) waddch(all_win->status_win, ACS_HLINE);
 					waddch(all_win->status_win, ACS_HLINE);
 				}else {
 					waddch(all_win->status_win, tab_pool[dummy].llpad);
-					for(dummy1 = 0; dummy1 < strlen(tab_pool[dummy].label); dummy1++) waddch(all_win->status_win, ' ');
+					for(dummy2 = 0; dummy2 < strlen(tab_pool[dummy].label); dummy2++) waddch(all_win->status_win, ' ');
 					waddch(all_win->status_win, tab_pool[dummy].lrpad);
 				}
 				for(dummy1 = 0; dummy1 < tab_pool[dummy].x; dummy1++) waddch(all_win->status_win, ACS_HLINE);
@@ -2547,8 +2525,7 @@ void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int
 			whline(all_win->status_win, ACS_HLINE, (all_win->status_win->_maxx-x));
 			mvwaddch(all_win->status_win, 1, all_win->status_win->_maxx, ACS_URCORNER);
 
-			get_stat(all_win, card_pool, tab_pool,
-			KEY_LEFT, no_cards);
+			get_stat(all_win, card_pool, tab_pool);
 
 			wrefresh(all_win->status_win);
 			wrefresh(all_win->cardlist);
@@ -2576,7 +2553,7 @@ void init_matrix(CARD *card_pool, TAB *tab_pool, int no_cards){
 	}
 }
 
-int init_card_pool(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int no_cards){
+int init_card_pool(CARD *card_pool, TAB *tab_pool, int no_cards){
 	card_pool[0].focus = '0';
 	init_matrix(card_pool, tab_pool, no_cards);
 return 1;
@@ -2676,14 +2653,14 @@ void trash_UI(SWINDOWS *all_win, int fail_stat){
 int build_UI(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int no_cards){
 	int dummy, fail_stat = 0;
 
-	if(!(init_card_pool(all_win, card_pool, tab_pool, no_cards))) {
+	if(!(init_card_pool(card_pool, tab_pool, no_cards))) {
 		fail_stat = INIT_CARD_FAIL;
 		goto hyper;
 	}
 
     all_win->root = initscr();
 	if(LINES < 25 || COLS < 80){
-		sprintf(err_msg, "Terminal size = %dx%d. Please resize your window to atleast 80x25.", COLS, LINES);
+		fprintf(stderr, "Terminal size = %dx%d. Please resize your window to atleast 80x25.", COLS, LINES);
 		trash_UI(all_win, BOTTOM_FAIL);
 		return 0;
 	}
@@ -2764,7 +2741,7 @@ int build_UI(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int no_cards){
 			box(all_win->status_win,0,0);
 
 		        mvwaddstr(all_win->title, 0, ((COLS/2)-16), "=<| VA RAID Monitor (VARMon) |>="); 
-		        mvwaddstr(all_win->title, 1, ((COLS/2)-26), "Ver. 1.1.0 by Dragan Stancevic <visitor@valinux.com> / Julien Danjou <julien@danjou.info>"); 
+		        mvwaddstr(all_win->title, 1, ((COLS/2)-25), "Ver. 1.2.1 by Julien Danjou <julien@danjou.info>"); 
 
 		        mvwaddstr(all_win->bottom, 0, 1, "<ESC> - Exit | <R> - Refresh | <RETURN> - Lock");
 		        mvwaddstr(all_win->cardlist, 0,1, "Detected cards");
@@ -3421,35 +3398,6 @@ void init_path(CARD * card_pool, int no_cards){
 	}
 }
 
-
-void clean_up(){
-	int count;
-	
-	printf("\n%s\n", err_msg);
-	
-	printf("\n-=<| VARMon  |>=- Starting clean up procedure ... 8^0\n");
-
-	if(!snap_all)
-		printf("-=<| VARMon  |>=- Nothing to clean. 8^\\\n");
-	else{
-	
-		/*Free the memory for Logical and Physical arrays per card*/
-		for(count = 0; count < no_pages; count++){
-
-			if(snap_all[count].ph_dev)
-				free(snap_all[count].ph_dev);
-			
-			if(snap_all[count].lg_drv)
-				free(snap_all[count].lg_drv);
-			
-		}
-		
-		free(snap_all);
-	}
-	
-	printf("\n-=<| VARMon  |>=- Done. Clean exit reached 8^)\n\n");
-}
-
 /*
 --------------------------------------------------------------------------------
 	Let there be varmon*/
@@ -3479,8 +3427,6 @@ int main(int argc, char **argv){
 		exit(1);
 	}
 	
-	atexit(&clean_up);
-	
 	count_cards(meet_p);	/*Count the number of cards
 							 and fill in the SNAPSHOT paths*/
 	closedir(meet_p);
